#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const read_pkg_up_1 = __importDefault(require("read-pkg-up"));
const lib_1 = __importDefault(require("./lib"));
const program = new commander_1.Command;
const pkg = read_pkg_up_1.default.sync({ cwd: __dirname });
const { name, version, description } = pkg.packageJson;
program
    .name(name)
    .version(version)
    .description(description)
    .option('-j, --json', 'output result as JSON')
    .arguments('<url> <js_snippet>')
    .action(main);
program.parse(process.argv);
if (program.args.length < 2)
    program.outputHelp();
async function main(url, snippet) {
    const evaluator = new lib_1.default(program.opts());
    const result = await evaluator.evalSnippet(url, snippet);
    console.log(result);
    await evaluator.close();
}
//# sourceMappingURL=cli.js.map